@@ -27,10 +27,6 @@ if [ "x${TMPPODIR}" = x ]; then
   exit 1
 fi
 
-if [ ! "x${DESTDIR}" = x ]; then
-  INST_LOCALEDIR="${DESTDIR}/${INST_LOCALEDIR}"
-fi
-
 msgfmtcmd=`which gmsgfmt 2>/dev/null`
 rc=$?
 if [ $rc -ne 0 -o "x$msgfmtcmd" = x ]; then
